@@ -536,6 +536,7 @@ impl TryFrom<tx_by_addr::TransactionError> for TransactionError {
                     47 => InstructionError::ArithmeticOverflow,
                     48 => InstructionError::UnsupportedSysvar,
                     49 => InstructionError::IllegalOwner,
+                    50 => InstructionError::AccountsDataBudgetExceeded,
                     _ => return Err("Invalid InstructionError"),
                 };
 
@@ -569,6 +570,10 @@ impl TryFrom<tx_by_addr::TransactionError> for TransactionError {
             20 => TransactionError::WouldExceedMaxAccountCostLimit,
             21 => TransactionError::WouldExceedMaxAccountDataCostLimit,
             22 => TransactionError::TooManyAccountLocks,
+            23 => TransactionError::AddressLookupTableNotFound,
+            24 => TransactionError::InvalidAddressLookupTableOwner,
+            25 => TransactionError::InvalidAddressLookupTableData,
+            26 => TransactionError::InvalidAddressLookupTableIndex,
             _ => return Err("Invalid TransactionError"),
         })
     }
@@ -645,6 +650,18 @@ impl From<TransactionError> for tx_by_addr::TransactionError {
                 TransactionError::TooManyAccountLocks => {
                     tx_by_addr::TransactionErrorType::TooManyAccountLocks
                 }
+                TransactionError::AddressLookupTableNotFound => {
+                    tx_by_addr::TransactionErrorType::AddressLookupTableNotFound
+                }
+                TransactionError::InvalidAddressLookupTableOwner => {
+                    tx_by_addr::TransactionErrorType::InvalidAddressLookupTableOwner
+                }
+                TransactionError::InvalidAddressLookupTableData => {
+                    tx_by_addr::TransactionErrorType::InvalidAddressLookupTableData
+                }
+                TransactionError::InvalidAddressLookupTableIndex => {
+                    tx_by_addr::TransactionErrorType::InvalidAddressLookupTableIndex
+                }
             } as i32,
             instruction_error: match transaction_error {
                 TransactionError::InstructionError(index, ref instruction_error) => {
@@ -799,6 +816,9 @@ impl From<TransactionError> for tx_by_addr::TransactionError {
                             InstructionError::IllegalOwner => {
                                 tx_by_addr::InstructionErrorType::IllegalOwner
                             }
+                            InstructionError::AccountsDataBudgetExceeded => {
+                                tx_by_addr::InstructionErrorType::AccountsDataBudgetExceeded
+                            }
                         } as i32,
                         custom: match instruction_error {
                             InstructionError::Custom(custom) => {
